@@ -1,14 +1,16 @@
-import Py_FS.filter
-import Py_FS.wrapper
-import Py_FS.evaluation
 import os,sys
 
 #  set the directory path
 dir_path = os.path.dirname(os.path.realpath(__file__))
 sys.path.insert(0, dir_path)
 
+import wrapper
+import filter
+import evaluation
+import datasets
+
 __all__ = [
-    "filter",
     "wrapper",
+    "filter",
     "evaluation",
 ]
