@@ -6,7 +6,6 @@ Mirjalili, S., Mirjalili, S. M., & Yang, X. S. (2014). Binary bat algorithm.
 Neural Computing and Applications, 25(3-4), 663-681.
 
 """
-
 import numpy as np
 import matplotlib.pyplot as plt
 import time
@@ -14,10 +13,8 @@ import time
 from sklearn.model_selection import train_test_split
 from sklearn import datasets
 
-from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
-from Py_FS.wrapper.nature_inspired._transfer_functions import get_trans_function
-# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
-# from _transfer_functions import get_trans_function
+from wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
+from wrapper.nature_inspired._transfer_functions import get_trans_function
 
 def BBA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitness, trans_function_shape='s', constantLoudness=True, save_conv_graph=False):
     
