@@ -7,7 +7,6 @@ This code has been developed according to the procedures mentioned in the follow
 'Red deer algorithm (RDA): a new nature-inspired meta-heuristic.''" Soft Computing (2020): 1-29."
 
 """
-
 import numpy as np
 import time
 import matplotlib.pyplot as plt
@@ -17,10 +16,8 @@ import sys
 from sklearn.model_selection import train_test_split
 from sklearn import datasets
 
-from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
-from Py_FS.wrapper.nature_inspired._transfer_functions import get_trans_function
-# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
-# from _transfer_functions import get_trans_function
+from wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
+from wrapper.nature_inspired._transfer_functions import get_trans_function
 
 
 def RDA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitness, trans_function_shape='s', save_conv_graph=False):
